==> amarok-2.1.80.tar.bz2: amarok-2.1.80/src/collection/iphoneos/support/IphoneOsConnectionAssistant.h <==
/****************************************************************************************
 * Copyright (c) 2009 Alejandro Wainzinger <aikawarazuni@gmail.com>                     *
 *                                                                                      *
 * This program is free software; you can redistribute it and/or modify it under        *
 * the terms of the GNU General Public License as published by the Free Software        *
 * Foundation; either version 2 of the License, or (at your option) any later           *
 * version.                                                                             *
 *                                                                                      *
 * This program is distributed in the hope that it will be useful, but WITHOUT ANY      *
 * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A      *
 * PARTICULAR PURPOSE. See the GNU General Public License for more details.              *
 *                                                                                      *
 * You should have received a copy of the GNU General Public License along with         *
 * this program.  If not, see <http://www.gnu.org/licenses/>.                           *
 ****************************************************************************************/

#ifndef IPODCONNECTIONASSISTANT_H
#define IPODCONNECTIONASSISTANT_H

#include "ConnectionAssistant.h"

#include <QObject>

class IphoneOsConnectionAssistant : public ConnectionAssistant
{
    Q_OBJECT
    
public:
    virtual ~IphoneOsConnectionAssistant();

    virtual bool identify( const QString& udi );
    virtual MediaDeviceInfo* deviceInfo( const QString& udi );

};

#endif // IPODCONNECTIONASSISTANT_H

==> amarok-2.1.85.tar.bz2: amarok-2.1.85/src/collection/iphoneos/support/IphoneOsConnectionAssistant.h <==
/****************************************************************************************
 * Copyright (c) 2009 Alejandro Wainzinger <aikawarazuni@gmail.com>                     *
 *                                                                                      *
 * This program is free software; you can redistribute it and/or modify it under        *
 * the terms of the GNU General Public License as published by the Free Software        *
 * Foundation; either version 2 of the License, or (at your option) any later           *
 * version.                                                                             *
 *                                                                                      *
 * This program is distributed in the hope that it will be useful, but WITHOUT ANY      *
 * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A      *
 * PARTICULAR PURPOSE. See the GNU General Public License for more details.             *
 *                                                                                      *
 * You should have received a copy of the GNU General Public License along with         *
 * this program.  If not, see <http://www.gnu.org/licenses/>.                           *
 ****************************************************************************************/

#ifndef IPHONEOSCONNECTIONASSISTANT_H
#define IPHONEOSCONNECTIONASSISTANT_H

#include "ConnectionAssistant.h"

#include <QObject>

class IphoneOsConnectionAssistant : public ConnectionAssistant
{
    Q_OBJECT
    
public:
    virtual ~IphoneOsConnectionAssistant();

    virtual bool identify( const QString& udi );
    virtual MediaDeviceInfo* deviceInfo( const QString& udi );

};

#endif // IPHONEOSCONNECTIONASSISTANT_H
